==> 3.5.3.zip: friendica/doc/de/Home.md <==
Friendica - Dokumentation und Ressourcen
=====================================

**Inhalte**

* Allgemeine Funktionen - Erste Schritte
	* [Account - Basics](help/Account-Basics)
	* [Schnellstart für neue Benutzer](help/Quick-Start-guide)
	* [Beiträge erstellen](help/Text_editor)
	* [Referenz der BBCode Elemente](help/BBCode)
	* [Beiträge kommentieren, einordnen und löschen](help/Text_comment)
	* [Profile](help/Profiles)
	* [Referenz der Accesskeys](help/Accesskeys)
    * [Veranstaltungen](help/events) (EN)
* Du und andere Nutzer
	* [Konnektoren (Connectors)](help/Connectors)
	* [Freunde finden](help/Making-Friends)
	* [Gruppen und Privatsphäre](help/Groups-and-Privacy)
	* [Tags und Erwähnungen](help/Tags-and-Mentions)
	* [Community-Foren](help/Forums)
	* [Chats](help/Chats)
* Weiterführende Informationen
	* [Account umziehen](help/Move-Account)
	* [Account löschen](help/Remove-Account)
	* [Bugs und Probleme](help/Bugs-and-Issues)
	* [Häufig gestellte Fragen (FAQ)](help/FAQ)

**Dokumentation für Administratoren**

* [Installation](help/Install)
* [Konfigurationen & Admin-Panel](help/Settings)
* [Plugins](help/Plugins)
* [Konnektoren (Connectors) installieren (Twitter/GNU Social)](help/Installing-Connectors)
* [Installation eines ejabberd Servers (XMPP-Chat) mit synchronisierten Anmeldedaten](help/install-ejabberd) (EN)
* [Betreibe deine Seite mit einem SSL-Zertifikat](help/SSL)
* [Konfigurationswerte, die nur in der .htconfig.php gesetzt werden können](help/htconfig) (EN)
* [Performance verbessern](help/Improve-Performance)

**Dokumentation für Entwickler**

* [Entwickler](help/Developers)
* [Where to get started?](help/Developers-Intro) (EN)
* [Help on Github](help/Github)
* [Help on Vagrant](help/Vagrant)
* [How to translate Friendica](help/translations) (EN)
* [Bugs and Issues](help/Bugs-and-Issues)
* [Plugin Development](help/Plugins)
* [Theme Development](help/themes)
* [Smarty 3 Templates](help/smarty3-templates)
* [Protokoll Dokumentation](help/Protocol) (EN)
* [Datenbank-Schema](help/database)
* [Class Autoloading](help/autoloader) (EN)
* [Using Composer](help/Composer) (EN)
* [Code-Referenz (mit doxygen generiert - setzt Cookies)](doc/html/)
* [Twitter/GNU Social API Functions](help/api) (EN)
* [Translation of Friendica](help/translations) (EN)

**Externe Ressourcen**

* [Haupt-Webseite](http://friendica.com)
* [Mailing Liste](http://librelist.com/browser/friendica/)
* [Deutsches Friendica-Wiki](http://wiki.toktan.org/doku.php)

**Über diese Seite**

* [Seite/Friendica-Version](friendica)
* [Mitwirkenden bei Friendica](credits)

==> 2020.07.zip: friendica/doc/de/Home.md <==
Friendica - Dokumentation und Ressourcen
=====================================

**Inhalte**

* Allgemeine Funktionen - Erste Schritte
	* [Account - Basics](help/Account-Basics)
	* [Schnellstart für neue Benutzer](help/Quick-Start-guide)
	* [Beiträge erstellen](help/Text_editor)
	* [Referenz der BBCode Elemente](help/BBCode)
	* [Beiträge kommentieren, einordnen und löschen](help/Text_comment)
	* [Referenz der Accesskeys](help/Accesskeys)
    * [Veranstaltungen](help/events)
* Du und andere Nutzer
	* [Konnektoren (Connectors)](help/Connectors)
	* [Freunde finden](help/Making-Friends)
	* [Gruppen und Privatsphäre](help/Groups-and-Privacy)
	* [Tags und Erwähnungen](help/Tags-and-Mentions)
	* [Community-Foren](help/Forums)
	* [Chats](help/Chats)
* Weiterführende Informationen
	* [Account umziehen](help/Move-Account)
	* [Export / Import gefolgter Kontakte](help/Export-Import-Contacts)
	* [Account löschen](help/Remove-Account)
	* [Bugs und Probleme](help/Bugs-and-Issues)
	* [Häufig gestellte Fragen (FAQ)](help/FAQ)

**Dokumentation für Administratoren**

* [Installation](help/Install)
* [Update](help/Update) (EN)
* [Konfigurationen & Admin-Panel](help/Settings)
* [Addons](help/Addons)
* [Konnektoren (Connectors) installieren (Twitter/GNU Social)](help/Installing-Connectors)
* [Installation eines ejabberd Servers (XMPP-Chat) mit synchronisierten Anmeldedaten](help/install-ejabberd) (EN)
* [Betreibe deine Seite mit einem SSL-Zertifikat](help/SSL)
* [Konfigurationswerte, die nur in der config/local.config.php gesetzt werden können](help/Config) (EN)
* [Performance verbessern](help/Improve-Performance)
* [Administration Werkzeuge](help/tools) (EN)

**Dokumentation für Entwickler**

* [Entwickler](help/Developers)
* [Where to get started?](help/Developers-Intro) (EN)
* [Help on Github](help/Github)
* [Help on Vagrant](help/Vagrant)
* [How to translate Friendica](help/translations) (EN)
* [Bugs and Issues](help/Bugs-and-Issues)
* [Addon Development](help/Addons)
* [Theme Development](help/themes)
* [Smarty 3 Templates](help/smarty3-templates)
* [Protokoll Dokumentation](help/Protocol) (EN)
* [Datenbank-Schema](help/database)
* [Class Autoloading](help/autoloader) (EN)
* [Using Composer](help/Composer) (EN)
* [Code-Referenz (mit doxygen generiert - setzt Cookies)](doc/html/)
* [Twitter/GNU Social API Functions](help/api) (EN)
* [Translation of Friendica](help/translations) (EN)
* [Run tests](help/Tests) (EN)

**Externe Ressourcen**

* [Haupt-Webseite](https://friendi.ca)
* [Deutsches Friendica-Wiki](https://friendica-wiki.de)
* Support Kanäle
  * [Friendica Support Forum](https://forum.friendi.ca/~helpers)
  * [Mailing Listen Archiv](http://mailman.friendi.ca/mailman/listinfo/support-friendi.ca) zum Abonnieren der Liste eine E-Mail an ``support-request(at)friendi.ca?subject=subscribe`` senden
  * XMPP/Jabber MUC: support(at)forum.friendi.ca
  * IRC: #friendica auf irc.freenode.net
  * Matrix: #friendi.ca oder #friendica auf matrix.org

**Über diese Seite**

* [Seite/Friendica-Version](friendica)
* [Mitwirkenden bei Friendica](credits)
